/*
 * DRV8770 Firmware 0.1.0
 *
 * This firmware is loaded on the DRV8770EVM boards and allows users to
 * control the DRV8770 devices on the board using the potentiometers.
 *
 * Copyright (C) 2021 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************
*  MSP430G2553 / DRV8770EVM
*  SW REV 0.1.0
*
*  Description: Using DRV82xx Customer EVM, potentiometers "IN1 PWM", and
*  "IN2 PWM" set the duty cycles for the PWM signals to the EN/IN1 and
*  PH/IN2 pins of the DRV82xx. The MODE_nSLEEP jumper selects the mode for which the
*  DRV82xx will interpret the input signals.
*
*  Board Function          MSP430G2553
*  PWM INHA output         P2.0 (TA1.0)
*  PWM INLA output         P2.1 (TA1.1)
*  PWM INHB output         P2.4 (TA1.2)
*  PWM INLB output         P2.6 (TA0.1)
*  Speed Ref1 Pot          P1.0 (A0 in)
*  Speed Ref2 Pot          P1.1 (A1 in)
*  ISENSE ref3 Pot         P1.2 (A2 in)
*  ISENSE_A                P1.3 (A3 in)
*  ISENSE_B                P1.4 (A4 in)
*  Status_LED              P2.7 (output)
******************************************************************************/
#include "msp430g2553.h"

// Pins Assignment
#define REF1        BIT0                 // P1.0
#define REF2        BIT1                 // P1.1
#define REF3        BIT2                 // P1.2
#define ISENSE_A    BIT3                 // P1.3
#define ISENSE_B    BIT4                 // P1.4
#define INHA        BIT0                 // P2.0
#define INLA        BIT1                 // P2.1
#define INHB        BIT4                 // P2.4
#define INLB        BIT6                 // P2.6
#define STATUS_LED  BIT7                 // P2.7

// Variable Definitions
int adc_ref1;                    // adc conversion results for REF1 (A0) channel
int adc_ref2;                    // adc conversion results for REF2 (A1) channel
int adc_ref3;                    // adc conversion results for REF3 (A2) channel
int INA_DC;                              // INHA PWM Duty Cycle
int INB_DC;                              // INHB PWM Duty Cycle
