/*
 * DRV8770 Firmware 0.1.0
 *
 * This firmware is loaded on the DRV8770EVM boards and allows users to
 * control the DRV8770 devices on the board using the potentiometers.
 *
 * Copyright (C) 2021 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************
*  MSP430G2553 / DRV8770EVM
*  SW REV 0.1.0
*
*  Description: Using DRV8770 Customer EVM, potentiometers "IN1_PWM", and
*  "IN2_PWM" set the duty cycles for the PWM signals to the INHA, INLA, INHB, and
*  INLB pins of the DRV8770.
*
*  Board Function          MSP430G2553
*  PWM INHA output         P2.0 (TA1.0)
*  PWM INLA output         P2.1 (TA1.1)
*  PWM INHB output         P2.4 (TA1.2)
*  PWM INLB output         P2.6 (TA0.1)
*  Speed Ref1 Pot          P1.0 (A0 in)
*  Speed Ref2 Pot          P1.1 (A1 in)
*  ISENSE ref3 Pot         P1.2 (A2 in)
*  ISENSE_A                P1.3 (A3 in)
*  ISENSE_B                P1.4 (A4 in)
*  Status_LED              P2.7 (output)
******************************************************************************/

#include "msp430g2553.h"
#include "definitions.h"

/**
 * main.c
 */
int main(void)
{
    WDTCTL = WDTPW + WDTHOLD;                           // Stop watchdog timer

    // Configure Pins
    P1OUT = 0x00;                                       // P1.x Reset - outputs low
    P2OUT = 0x00;                                       // P2.x reset - outputs low
    P2DIR |= INHA + INLA + INHB + INLB + STATUS_LED;    // Set P2.x pins as output
    P2SEL  = INLA + INHB + INLB;                        // Set P2.1, P2.4, P2.6 as timer outputs
    P2SEL2 = 0;                                         // Set P2SEL2=0 to configure P2.1, P2.4, P2.6 as timer outputs

   // Configure ADC
    ADC10CTL1 = CONSEQ_0;                        // single channel single sequence
    ADC10CTL0 |= ADC10SHT_2 + ADC10ON;           // Configure ADC CTLO register
    ADC10AE0 |= REF1 + REF2;                     // P1.0 ADC option select

    P2OUT |=  STATUS_LED;                        // STATUS LED on

    TA1CCR0 = 50-1;                              // Period = 51/1MHz = 50s ~ 20kHz
    TA1CCTL1 |= OUTMOD_7;                        // Reset/Set, interrupt enabled
    TA1CCTL2 |= OUTMOD_7;                        // Reset/Set, interrupt enabled
    TA1CCR1 = 0;
    TA1CCR2 = 0;
    TAR = 0;
    TA1CTL |= TASSEL_2 + MC_1 + TACLR;           // SMCLK (1MHz), upmode, clear TAR

      for(;;)
    {

    //REF1 (A0) ADC conversion
    ADC10CTL0 &= ~ENC & ~ADC10SC;                // Disable ADC conversion
    ADC10CTL1 &= ~INCH_1;                        // A0 selected
    ADC10CTL1 |= INCH_0;                         // A0 selected
    ADC10CTL0 |= ENC + ADC10SC;                  // Enabled ADC conversion
    while (ADC10CTL1 & ADC10BUSY);               // ADC10BUSY?
    adc_ref1 = ADC10MEM/20;                      // Store and scale down ADC results for REF1


    //REF2 (A1) ADC conversion
    ADC10CTL0 &= ~ENC & ~ADC10SC;                // Disable ADC conversion
    ADC10CTL1 &= ~INCH_0;                        // A0 selected
    ADC10CTL1 |= INCH_1;                         // A0 selected
    ADC10CTL0 |= ENC + ADC10SC;                  // Enable ADC conversion
    while (ADC10CTL1 & ADC10BUSY);               // ADC10BUSY?
    adc_ref2 = ADC10MEM/20;                      // Store and scale down ADC results for REF2

    TA1CCR1 = adc_ref1;                          // Set INHA and INLA duty cycle
    TA1CCR2 = adc_ref2;                          // Set INHB and INLB duty cycle
  }
}
